<?php

namespace Drupal\important_information\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;


/**
 * Configure important_information content.
 */
class ImportantInformationSettingsForm extends ConfigFormBase {
  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'important_information_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'important_information.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $settings = $this->config('important_information.settings');
/*
    // Sidebar
    $sidebar_parent = $settings->get('sidebar_parent');
    $sidebar_container = $settings->get('sidebar_container');
    $form['sidebar'] = array(
      '#type' => 'details',
      '#title' => $this->t('Sticky Sidebar Settings'),
      '#collapsible' => TRUE,
    );
    $form['sidebar']['sidebar_parent'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Parent'),
      '#default_value' => isset($sidebar_parent) ? $sidebar_parent: '',
      '#description' => $this->t('See https://abouolia.github.io/sticky-sidebar/#usage for more information.'),
    ];
    $form['sidebar']['sidebar_container'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Container'),
      '#default_value' => isset($sidebar_container) ? $sidebar_container: '',
      '#description' => $this->t('See https://abouolia.github.io/sticky-sidebar/#usage for more information.'),
    ];
*/
    // Floating Container
    $collapsed_percent = $settings->get('collapsed_percent');
    $container_hide = $settings->get('container_hide');
    $offset = $settings->get('offset');
    $full_size = $settings->get('full_size');
    $modal_width = $settings->get('modal_width');
    $expandable= $settings->get('expandable');
    $expandable_amount = $settings->get('expandable_amount');
    $expand_button_markup = $settings->get('expand_button_markup');
    $shrink_button_markup = $settings->get('shrink_button_markup');
    
    // Floating Container Sidebar
    $container_sidebar_behavior = $settings->get('container_sidebar_behavior');
    $container_sidebar_y_offset = $settings->get('container_sidebar_y_offset');
    $full_size_sidebar = $settings->get('full_size_sidebar');
    $modal_width_sidebar = $settings->get('modal_width_sidebar');

    // Bottom Container
    $full_size_bottom = $settings->get('full_size_bottom');
    $bottom_modal_width = $settings->get('bottom_modal_width');

    // Acknowledge Container
    $ack_modal_width = $settings->get('ack_modal_width');

    // Exit Container
    $exit_modal_width = $settings->get('exit_modal_width');

    $form['container_sidebar'] = array(
      '#type' => 'details',
      '#title' => $this->t('Floating Container Sidebar Settings'),
      '#collapsible' => TRUE,
    );
    $options = [
      'absolute' => $this->t('Sidebar is stuck in the same position, absolutely positioned'),
      'fixed' => $this->t('Sidebar is stuck in the same position, ensuring that it is always in the same place relative to the viewport (i.e. floating in place), fixed position'),
      'absolute_fixed' => $this->t('Sidebar starts absolutely positioned, but switches to fixed at a certain distance while the user scrolls down the page.'),
    ];
    $form['container_sidebar']['container_sidebar_behavior'] = [
      '#type' => 'radios',
      '#title' => $this->t('Behavior'),
      '#options' => $options,
      '#default_value' => $container_sidebar_behavior ? $container_sidebar_behavior : 'absolute',
      '#description' => $this->t('Choose the behavior the Floating Container Sidebar should have.'),
      '#multiple' => FALSE,
    ];
    $form['container_sidebar']['container_sidebar_y_offset'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Vertical Offset'),
      '#default_value' => $container_sidebar_y_offset ? $container_sidebar_y_offset : '0',
      '#description' => $this->t('Set the placement of the Floating Container Sidebar, in pixels (numbers only). Also serves as the Y position at which absolute switches to fixed if that is the behavior option set.'),
    ];
    $form['container_sidebar']['full_size_sidebar'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Full-size Modal'),
      '#default_value' => $full_size_sidebar ? $full_size_sidebar: FALSE,
      '#description' => $this->t('Provides a button to present the Important Information in a full screen modal.'),
    ];
    $form['container_sidebar']['modal_width_sidebar'] = [
      '#type' => 'textfield',
      '#title' => $this->t('% of Modal Width'),
      '#default_value' => $modal_width_sidebar ? $modal_width_sidebar: IMPORTANT_INFORMATION_MODAL_WIDTH_PERCENT_DEFAULT,
      '#description' => $this->t('Percent of the screen modal will cover.'),
    ];

    $form['floating_container'] = array(
      '#type' => 'details',
      '#title' => $this->t('Floating Container Settings'),
      '#collapsible' => TRUE,
    );
    $form['floating_container']['full_size'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Full-size Modal'),
      '#default_value' => $full_size ? $full_size: FALSE,
      '#description' => $this->t('Provides a button to present the Important Information in a full screen modal.'),
    ];
    $form['floating_container']['modal_width'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Percent of the screen modal will cover'),
      '#default_value' => $modal_width ? $modal_width: IMPORTANT_INFORMATION_MODAL_WIDTH_PERCENT_DEFAULT,
      '#description' => $this->t('Numbers only, do not add the %.'),
    ];
    $form['floating_container']['collapsed_percent'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Percentage of the screen the collapsed Floating Container occupies'),
      '#default_value' => $collapsed_percent ? $collapsed_percent: IMPORTANT_INFORMATION_FOOTER_COLLAPSED_PERCENT_DEFAULT,
      '#description' => $this->t('Numbers only, do not add the %.'),
    ];
    $form['floating_container']['expandable'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Expand Button'),
      '#default_value' => $expandable ? $expandable: FALSE,
      '#description' => $this->t('Allows the user to expand the footer to see more of the content.'),
    ];
    $form['floating_container']['expandable_amount'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Percentage of the screen the expanded Floating Container will cover'),
      '#default_value' => $expandable_amount ? $expandable_amount : IMPORTANT_INFORMATION_FOOTER_EXPANDED_PERCENT_DEFAULT,
      '#description' => $this->t('Numbers only, do not add the %.'),
    ];
    $form['floating_container']['expand_button_markup'] =[
      '#type' => 'text_format',
      '#title' => 'Expand Button',
      '#format' => $expand_button_markup['format'] ? $expand_button_markup['format'] : NULL,
      '#default_value' => $expand_button_markup['value'] ? $expand_button_markup['value'] : $this->t('Expand'),
      '#description'  => $this->t('Set markup for the expand button.'),
    ];
    $form['floating_container']['shrink_button_markup'] = [
      '#type' => 'text_format',
      '#title' => 'Un-expand button',
      '#format' => $shrink_button_markup['format'] ? $shrink_button_markup['format'] : NULL,
      '#default_value' => $shrink_button_markup['value'] ? $shrink_button_markup['value'] : $this->t('Collapse'),
      '#description'  => $this->t('Set markup for the un-expand button.'),
    ];

    $form['bottom_container'] = array(
      '#type' => 'details',
      '#title' => $this->t('Embedded Bottom Container Settings'),
      '#collapsible' => TRUE,
    );
    $form['bottom_container']['container_hide'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Hide Floating Container'),
      '#default_value' => $container_hide ? $container_hide: FALSE,
      '#description' => $this->t('When Embedded Bottom is in the viewport, Floating Container will be hidden.'),
    ];
    $form['bottom_container']['offset'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Hide/show Offset'),
      '#default_value' => $offset ? $offset: 0,
      '#description' => $this->t('Adjust the calibration of the Embedded Bottom detection; lower than zero makes it happen slower.'),
    ];
    $form['bottom_container']['full_size_bottom'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Full-size Modal'),
      '#default_value' => $full_size_bottom ? $full_size_bottom: FALSE,
      '#description' => $this->t('Provides a button to present the Important Information in a full screen modal.'),
    ];
    $form['bottom_container']['bottom_modal_width'] = [
      '#type' => 'textfield',
      '#title' => $this->t('% of Exit Modal Width'),
      '#default_value' => $bottom_modal_width ? $bottom_modal_width: IMPORTANT_INFORMATION_MODAL_WIDTH_PERCENT_DEFAULT,
      '#description' => $this->t('Percent of the screen modal will cover.'),
    ];

    $form['exit_container'] = array(
      '#type' => 'details',
      '#title' => $this->t('Leaving Interstitial Container Settings'),
      '#collapsible' => TRUE,
    );
    $form['exit_container']['exit_modal_width'] = [
      '#type' => 'textfield',
      '#title' => $this->t('% of Exit Modal Width'),
      '#default_value' => $exit_modal_width ? $exit_modal_width: IMPORTANT_INFORMATION_MODAL_WIDTH_PERCENT_DEFAULT,
      '#description' => $this->t('Percent of the screen modal will cover.'),
    ];

    $form['acknowledge_container'] = array(
      '#type' => 'details',
      '#title' => $this->t('Acknowledge Container Settings'),
      '#collapsible' => TRUE,
    );
    $form['acknowledge_container']['ack_modal_width'] = [
      '#type' => 'textfield',
      '#title' => $this->t('% of Modal Width'),
      '#default_value' => $ack_modal_width ? $ack_modal_width: IMPORTANT_INFORMATION_MODAL_WIDTH_PERCENT_DEFAULT,
      '#description' => $this->t('Percent of the screen modal will cover.'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->configFactory->getEditable('important_information.settings')
      // Set the submitted configuration setting
      //->set('sidebar_parent', $form_state->getValue('sidebar_parent'))
      //->set('sidebar_container', $form_state->getValue('sidebar_container'))
      ->set('container_hide', $form_state->getValue('container_hide'))
      ->set('offset', $form_state->getValue('offset'))
      ->set('full_size', $form_state->getValue('full_size'))
      ->set('modal_width', $form_state->getValue('modal_width'))
      ->set('collapsed_percent', $form_state->getValue('collapsed_percent'))
      ->set('expandable', $form_state->getValue('expandable'))
      ->set('expandable_amount', $form_state->getValue('expandable_amount'))
      ->set('expand_button_markup', $form_state->getValue('expand_button_markup'))
      ->set('shrink_button_markup', $form_state->getValue('shrink_button_markup'))
      ->set('ack_modal_width', $form_state->getValue('ack_modal_width'))
      ->set('exit_modal_width', $form_state->getValue('exit_modal_width'))
      ->set('container_sidebar_behavior', $form_state->getValue('container_sidebar_behavior'))
      ->set('container_sidebar_y_offset', $form_state->getValue('container_sidebar_y_offset'))
      ->set('full_size_sidebar', $form_state->getValue('full_size_sidebar'))
      ->set('modal_width_sidebar', $form_state->getValue('modal_width_sidebar'))
      ->set('full_size_bottom', $form_state->getValue('full_size_bottom'))
      ->set('bottom_modal_width', $form_state->getValue('bottom_modal_width'))
      ->save();

    parent::submitForm($form, $form_state);
  }
}