<?php
/**
 * @file
 */
namespace Drupal\important_information\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\Core\Link;
use Drupal\Component\Serialization\Json;
use Drupal\Core\Form\ConfigFormBase;


/**
 * Provides an Important Information block that floats above the site, hugging
 * the bottom of the viewport.
 *
 * @Block(
 *   id = "embedded_bottom",
 *   admin_label = @Translation("Important Information: Embedded Bottom"),
 *   category = @Translation("Important Information")
 * )
 */
class EmbeddedBottom extends BlockBase {
  /**
   * {@inheritdoc}
   */
  public function build() {

    // Load module settings
    $settings = \Drupal::config('important_information.settings');
    $container_hide = $settings->get('container_hide');
    $offset = $settings->get('offset');

    // Load content config.
    $content = \Drupal::config('important_information.content');

    $important_information_value = $content->get('important_information_value');
    $important_information_format = $content->get('important_information_format');

    $prefix_value = $content->get('bottom_prefix_value');
    $prefix_format = $content->get('bottom_prefix_format');

    $suffix_value = $content->get('bottom_suffix_value');
    $suffix_format = $content->get('bottom_suffix_format');

    $info_prefix = array(
      '#type' => 'processed_text',
      '#text' => $prefix_value,
      '#format' => $prefix_format,
    );
    $information = array(
      '#type' => 'processed_text',
      '#text' => $important_information_value,
      '#format' => $important_information_format,
    );
    $info_suffix = array(
      '#type' => 'processed_text',
      '#text' => $suffix_value,
      '#format' => $suffix_format,
    );

    // Format information via TPL
    $variables = array(
      '#type' => 'markup',
      '#theme' => 'important_information_bottom',
      '#information' => $information,
      '#info_prefix' => isset($prefix_value) ?  $info_prefix : FALSE,
      '#info_suffix' => isset($suffix_value) ?  $info_suffix : FALSE,
      '#attached' => array(
        'library' => array(
          'important_information/importantInformationBottom',
        ),
      ),
    );
  
  $full_size = $settings->get('full_size_bottom');
  
  // Check for Modal
  if ($full_size == 1) {
    $link_url = Url::fromRoute('important_information.bottom');
    $link_url->setOptions([
      'attributes' => [
        'class' => ['use-ajax', 'button', 'button--small'],
        'data-dialog-type' => 'modal',
      ]
    ]);

    $variables['#modal'] =  array(
      '#type' => 'markup',
      '#markup' => Link::fromTextAndUrl(t('Full size'), $link_url)->toString(),
    );
    $variables['#attached']['library'][] = 'core/drupal.dialog.ajax';
  }

  // Add block and module configuration to settings.
  $variables['#attached']['drupalSettings']['important_information']['importantInformationBottom'] = array(
    'showHideFloatingContainer' => $container_hide ? $container_hide : FALSE,
    'offset' => $offset ? $offset : 0,
  );
  
  return $variables;
  }

}
