<?php
/**
 * @file
 */
namespace Drupal\important_information\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\Core\Link;
use Drupal\Component\Serialization\Json;

/**
 * Provides an Important Information block that floats above the site, hugging
 * the bottom of the viewport.
 *
 * @Block(
 *   id = "floating_container",
 *   admin_label = @Translation("Important Information: Floating Container"),
 *   category = @Translation("Important Information")
 * )
 */
class FloatingContainer extends BlockBase {
  /**
   * {@inheritdoc}
   */
  public function build() {
    
    // Load module settings
    $settings = \Drupal::config('important_information.settings');

    // Load content config.
    $content = \Drupal::config('important_information.content');

    $important_information_value = $content->get('important_information_value');
    $important_information_format = $content->get('important_information_format');

    $prefix_value = $content->get('container_prefix_value');
    $prefix_format = $content->get('container_prefix_format');

    $suffix_value = $content->get('container_suffix_value');
    $suffix_format = $content->get('container_suffix_format');

    $info_prefix = array(
      '#type' => 'processed_text',
      '#text' => $prefix_value,
      '#format' => $prefix_format,
    );
    $information = array(
      '#type' => 'processed_text',
      '#text' => $important_information_value,
      '#format' => $important_information_format,
    );
    $info_suffix = array(
      '#type' => 'processed_text',
      '#text' => $suffix_value,
      '#format' => $suffix_format,
    );
    
    // Load block Config.
    $config = $this->getConfiguration();

    // Format information via TPL
    $variables = array(
      '#type' => 'markup',
      '#theme' => 'important_information_floating_container',
      '#information' => $information,
      '#info_prefix' => isset($prefix_value) ?  $info_prefix : FALSE,
      '#info_suffix' => isset($suffix_value) ?  $info_suffix : FALSE,
      '#attached' => array(
        'library' => array(
          'important_information/importantInformationFloatingContainer',
        ),
      ),
    );

    $full_size = $settings->get('full_size');

    // Check for Modal
    if ($full_size == 1) {
      $link_url = Url::fromRoute('important_information.floating');
      $link_url->setOptions([
        'attributes' => [ 
          'class' => ['use-ajax', 'button', 'button--small'],
          'data-dialog-type' => 'modal',
        ]
      ]);

      $variables['#modal'] =  array(
        '#type' => 'markup',
        '#markup' => Link::fromTextAndUrl(t('Full size'), $link_url)->toString(),
      );
      $variables['#attached']['library'][] = 'core/drupal.dialog.ajax';
    }

    // Set height container
    $collapsed_percent = $settings->get('collapsed_percent');

    $variables['#attached']['drupalSettings']['important_information']['importantInformationHeightContainer'] = array(
      'heightAmount' => render($collapsed_percent),
    );

    $expandable= $settings->get('expandable');
    $expandable_amount = $settings->get('expandable_amount');
    $expand_button_markup = $settings->get('expand_button_markup');
    $shrink_button_markup = $settings->get('shrink_button_markup');

    // Check for Expandability
    if ($expandable == 1) {

      $expand_button_markup = array(
        '#type' => 'processed_text',
        '#text' => $expand_button_markup['value'],
        '#format' => $expand_button_markup['format'],
      );

      $variables['#expandable'] = TRUE;
      $variables['#default_expand_markup'] = $expand_button_markup;
      $variables['#attached']['library'][] = 'core/drupal.dialog.ajax';

      $shrink_button_markup = array(
        '#type' => 'processed_text',
        '#text' => $shrink_button_markup['value'],
        '#format' => $shrink_button_markup['format'],
      );

      // Add more scripts
      $variables['#attached']['drupalSettings']['important_information']['importantInformationFloatingContainer'] = array(
        'expandable' => TRUE,
        'expandMarkup' => render($expand_button_markup),
        'shrinkMarkup' => render($shrink_button_markup),
        'expandAmount' => $expandable_amount, 
        'heightAmount' => render($collapsed_percent),
      );
    }
    else {
      $variables['#expandable'] = FALSE;
      $variables['#attached']['drupalSettings']['important_information']['importantInformationFloatingContainer'] = array(
        'expandable' => FALSE
      );
    }

    return $variables;
  }

}
