<?php
/**
 * @file
 */
namespace Drupal\important_information\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\Core\Link;
use Drupal\Component\Serialization\Json;

/**
 * Provides an Important Information block that floats above the site, hugging
 * the bottom of the viewport.
 *
 * @Block(
 *   id = "floating_container_sidebar",
 *   admin_label = @Translation("Important Information: Floating Container Sidebar"),
 *   category = @Translation("Important Information")
 * )
 */
class FloatingContainerSidebar extends BlockBase {
  /**
   * {@inheritdoc}
   */
  public function build() {

    $content = \Drupal::config('important_information.content');

    $important_information_value = $content->get('important_information_value');
    $important_information_format = $content->get('important_information_format');

    $prefix_value = $content->get('container_sidebar_prefix_value');
    $prefix_format = $content->get('container_sidebar_prefix_format');

    $suffix_value = $content->get('container_sidebar_suffix_value');
    $suffix_format = $content->get('container_sidebar_suffix_format');

    $info_prefix = array(
      '#type' => 'processed_text',
      '#text' => $prefix_value,
      '#format' => $prefix_format,
    );
    $information = array(
      '#type' => 'processed_text',
      '#text' => $important_information_value,
      '#format' => $important_information_format,
    );
    $info_suffix = array(
      '#type' => 'processed_text',
      '#text' => $suffix_value,
      '#format' => $suffix_format,
    );

    // Load content config.
    $settings = \Drupal::config('important_information.settings');
    $container_sidebar_y_offset = $settings->get('container_sidebar_y_offset');
    $container_sidebar_behavior = $settings->get('container_sidebar_behavior');
    $full_size = $settings->get('full_size_sidebar');

    // Format information via TPL
    $variables = array(
      '#type' => 'markup',
      '#theme' => 'important_information_floating_container_sidebar',
      '#information' => $information,
      '#info_prefix' => isset($prefix_value) ?  $info_prefix : FALSE,
      '#info_suffix' => isset($suffix_value) ?  $info_suffix : FALSE,
      '#y_offset' => $container_sidebar_y_offset,
      '#behavior' => $container_sidebar_behavior,
      '#attached' => array(
        'library' => array(
          'important_information/importantInformationFloatingContainerSidebar',
        ),
      ),
    );

  // Check for Modal
  if ($full_size == 1) {
    $link_url = Url::fromRoute('important_information.sidebar');
    $link_url->setOptions([
      'attributes' => [
        'class' => ['use-ajax', 'button', 'button--small'],
        'data-dialog-type' => 'modal',
      ]
    ]);

    $variables['#modal'] =  array(
      '#type' => 'markup',
      '#markup' => Link::fromTextAndUrl(t('Full size'), $link_url)->toString(),
    );
    $variables['#attached']['library'][] = 'core/drupal.dialog.ajax';
  }

  // Add more scripts
  $variables['#attached']['drupalSettings']['important_information']['importantInformationFloatingContainerSidebar'] = array(
    'sidebarYOffset' => $container_sidebar_y_offset,
    'behavior' => $container_sidebar_behavior,
  );

  return $variables;
  }

}